Introduction
============

The :mod:`regridding` package aims to provide Numba-accelerated resampling of
logically-rectangular curvilinear grids.



API Reference
=============

.. autosummary::
    :toctree: _autosummary
    :template: module_custom.rst
    :recursive:

    regridding



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
